RoutingRole

Enum RoutingRole 

#[repr(u8)]
pub enum RoutingRole { Unspecified = 0, Unassigned = 1, Sleepyenddevice = 2, Enddevice = 3, Reed = 4, Router = 5, Leader = 6, }

Variants



Unspecified = 0

Unspecified routing role.



Unassigned = 1

The Node does not currently have a role as a result of the Thread interface not currently being configured or operational.



Sleepyenddevice = 2

The Node acts as a Sleepy End Device with RX-off-when-idle sleepy radio behavior.



Enddevice = 3

The Node acts as an End Device without RX-off-when-idle sleepy radio behavior.



Reed = 4

The Node acts as an Router Eligible End Device.



Router = 5

The Node acts as a Router Device.



Leader = 6

The Node acts as a Leader Device.

Implementations

Source

impl RoutingRole

pub fn from_u8(value: u8) -> Option<Self>

Convert from u8 value

pub fn to_u8(self) -> u8

Convert to u8 value